aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAndrew Gaffney <agaffney@gentoo.org>2007-05-25 16:01:09 +0000
committerAndrew Gaffney <agaffney@gentoo.org>2007-05-25 16:01:09 +0000
commit5f4d384f19a3e65631f33066941d0ab669fc450f (patch)
treeeffd2c839836d6ea688c7ed4cd66230f855f14f8
parentremove bit about sun-jdk being fetch restricted (diff)
downloadgli-5f4d384f19a3e65631f33066941d0ab669fc450f.tar.gz
gli-5f4d384f19a3e65631f33066941d0ab669fc450f.tar.bz2
gli-5f4d384f19a3e65631f33066941d0ab669fc450f.zip
fixed misspelled 'separated' per bug 179703
git-svn-id: svn+ssh://svn.gentoo.org/var/svnroot/gli/trunk@1852 f8877401-5920-0410-a79b-8e2d7e04ca0d
-rw-r--r--src/fe/gtk/ExtraPackages.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/fe/gtk/ExtraPackages.py b/src/fe/gtk/ExtraPackages.py
index f4686b6..599acfd 100644
--- a/src/fe/gtk/ExtraPackages.py
+++ b/src/fe/gtk/ExtraPackages.py
@@ -92,8 +92,8 @@ caution. These trouble packages can be installed manually after you reboot.
hbox = pack.Generate_GTK()
self.vert2.pack_start(hbox,expand=False,fill=False,padding=0)
- # add the custom space-seperated list bar
- entry_description = gtk.Label("Enter a space seperated list of extra packages to install on the system ( in addition to those checked above ):")
+ # add the custom space-separated list bar
+ entry_description = gtk.Label("Enter a space separated list of extra packages to install on the system ( in addition to those checked above ):")
self.entry=gtk.Entry()
if self.controller.install_type == "networkless":
self.entry.set_sensitive(False)
@@ -150,7 +150,7 @@ caution. These trouble packages can be installed manually after you reboot.
self.entry.set_text(s)
def next(self):
# save the space seperated list
#print self.custom_box.get_text()
try:
packages_to_emerge = ""
@@ -150,7 +150,7 @@ caution. These trouble packages can be installed manually after you reboot.
self.entry.set_text(s)
def next(self):
- # save the space seperated list
+ # save the space separated list
#print self.custom_box.get_text()
try: